summaryrefslogtreecommitdiffstats
path: root/kmail
diff options
context:
space:
mode:
Diffstat (limited to 'kmail')
-rw-r--r--kmail/accountdialog.cpp10
-rw-r--r--kmail/configuredialog_p.h2
-rw-r--r--kmail/customtemplates.cpp10
-rw-r--r--kmail/folderpropertiesdialog.ui4
-rw-r--r--kmail/folderrequester.cpp2
-rw-r--r--kmail/kmfawidgets.cpp2
-rw-r--r--kmail/kmfilterdlg.cpp18
-rw-r--r--kmail/kmfilterdlg.h4
-rw-r--r--kmail/kmfolderdia.cpp10
-rw-r--r--kmail/kmfolderdia.h6
-rw-r--r--kmail/kmfoldertree.cpp30
-rw-r--r--kmail/kmheaders.cpp4
-rw-r--r--kmail/kmmimeparttree.cpp2
-rw-r--r--kmail/kmmsgpart.h2
-rw-r--r--kmail/kmmsgpartdlg.cpp2
-rw-r--r--kmail/kmstartup.cpp2
-rw-r--r--kmail/kmsystemtray.cpp4
-rw-r--r--kmail/objecttreeparser.cpp6
-rw-r--r--kmail/partNode.cpp2
-rw-r--r--kmail/recipientspicker.cpp8
-rw-r--r--kmail/redirectdialog.cpp2
-rw-r--r--kmail/searchwindow.cpp4
-rw-r--r--kmail/simplestringlisteditor.cpp4
-rw-r--r--kmail/urlhandlermanager.cpp2
24 files changed, 71 insertions, 71 deletions
diff --git a/kmail/accountdialog.cpp b/kmail/accountdialog.cpp
index b1856bee..47184b73 100644
--- a/kmail/accountdialog.cpp
+++ b/kmail/accountdialog.cpp
@@ -908,7 +908,7 @@ void AccountDialog::makeImapAccountPage( bool connected )
button->setSizePolicy( TQSizePolicy( TQSizePolicy::Fixed, TQSizePolicy::Fixed ) );
button->setFixedSize( 22, 22 );
button->setIconSet(
- TDEGlobal::iconLoader()->loadIconSet( "reload", KIcon::Small, 0 ) );
+ TDEGlobal::iconLoader()->loadIconSet( "reload", TDEIcon::Small, 0 ) );
connect( button, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotReloadNamespaces()) );
TQWhatsThis::add( button,
i18n("Reload the namespaces from the server. This overwrites any changes.") );
@@ -922,7 +922,7 @@ void AccountDialog::makeImapAccountPage( bool connected )
mImap.personalNS->setReadOnly( true );
mImap.editPNS = new TQToolButton( listbox );
mImap.editPNS->setIconSet(
- TDEGlobal::iconLoader()->loadIconSet( "edit", KIcon::Small, 0 ) );
+ TDEGlobal::iconLoader()->loadIconSet( "edit", TDEIcon::Small, 0 ) );
mImap.editPNS->setAutoRaise( true );
mImap.editPNS->setSizePolicy( TQSizePolicy( TQSizePolicy::Fixed, TQSizePolicy::Fixed ) );
mImap.editPNS->setFixedSize( 22, 22 );
@@ -934,7 +934,7 @@ void AccountDialog::makeImapAccountPage( bool connected )
mImap.otherUsersNS->setReadOnly( true );
mImap.editONS = new TQToolButton( listbox );
mImap.editONS->setIconSet(
- TDEGlobal::iconLoader()->loadIconSet( "edit", KIcon::Small, 0 ) );
+ TDEGlobal::iconLoader()->loadIconSet( "edit", TDEIcon::Small, 0 ) );
mImap.editONS->setAutoRaise( true );
mImap.editONS->setSizePolicy( TQSizePolicy( TQSizePolicy::Fixed, TQSizePolicy::Fixed ) );
mImap.editONS->setFixedSize( 22, 22 );
@@ -946,7 +946,7 @@ void AccountDialog::makeImapAccountPage( bool connected )
mImap.sharedNS->setReadOnly( true );
mImap.editSNS = new TQToolButton( listbox );
mImap.editSNS->setIconSet(
- TDEGlobal::iconLoader()->loadIconSet( "edit", KIcon::Small, 0 ) );
+ TDEGlobal::iconLoader()->loadIconSet( "edit", TDEIcon::Small, 0 ) );
mImap.editSNS->setAutoRaise( true );
mImap.editSNS->setSizePolicy( TQSizePolicy( TQSizePolicy::Fixed, TQSizePolicy::Fixed ) );
mImap.editSNS->setFixedSize( 22, 22 );
@@ -2305,7 +2305,7 @@ NamespaceEditDialog::NamespaceEditDialog( TQWidget *parent,
edit->setText( it.key() );
TQToolButton* button = new TQToolButton( grid );
button->setIconSet(
- TDEGlobal::iconLoader()->loadIconSet( "editdelete", KIcon::Small, 0 ) );
+ TDEGlobal::iconLoader()->loadIconSet( "editdelete", TDEIcon::Small, 0 ) );
button->setAutoRaise( true );
button->setSizePolicy( TQSizePolicy( TQSizePolicy::Fixed, TQSizePolicy::Fixed ) );
button->setFixedSize( 22, 22 );
diff --git a/kmail/configuredialog_p.h b/kmail/configuredialog_p.h
index 596e8c6b..439393d3 100644
--- a/kmail/configuredialog_p.h
+++ b/kmail/configuredialog_p.h
@@ -55,7 +55,7 @@ class KMMsgTagDesc;
class TDEListBox;
class KColorCombo;
class TDEFontRequester;
-class KIconButton;
+class TDEIconButton;
class KKeyButton;
class TQSpinBox;
class KComboBox;
diff --git a/kmail/customtemplates.cpp b/kmail/customtemplates.cpp
index 30b3dcf9..bbbd0aec 100644
--- a/kmail/customtemplates.cpp
+++ b/kmail/customtemplates.cpp
@@ -60,8 +60,8 @@ CustomTemplates::CustomTemplates( TQWidget *parent, const char *name )
TQFont f = TDEGlobalSettings::fixedFont();
mEdit->setFont( f );
- mAdd->setIconSet( BarIconSet( "add", KIcon::SizeSmall ) );
- mRemove->setIconSet( BarIconSet( "remove", KIcon::SizeSmall ) );
+ mAdd->setIconSet( BarIconSet( "add", TDEIcon::SizeSmall ) );
+ mRemove->setIconSet( BarIconSet( "remove", TDEIcon::SizeSmall ) );
mList->setColumnWidth( 0, 50 );
mList->setColumnWidth( 1, 100 );
@@ -92,9 +92,9 @@ CustomTemplates::CustomTemplates( TQWidget *parent, const char *name )
connect( mKeyButton, TQT_SIGNAL( capturedShortcut( const TDEShortcut& ) ),
this, TQT_SLOT( slotShortcutCaptured( const TDEShortcut& ) ) );
- mReplyPix = KIconLoader().loadIcon( "mail_reply", KIcon::Small );
- mReplyAllPix = KIconLoader().loadIcon( "mail_replyall", KIcon::Small );
- mForwardPix = KIconLoader().loadIcon( "mail_forward", KIcon::Small );
+ mReplyPix = TDEIconLoader().loadIcon( "mail_reply", TDEIcon::Small );
+ mReplyAllPix = TDEIconLoader().loadIcon( "mail_replyall", TDEIcon::Small );
+ mForwardPix = TDEIconLoader().loadIcon( "mail_forward", TDEIcon::Small );
mType->clear();
mType->insertItem( TQPixmap(), i18n( "Message->", "Universal" ), TUniversal );
diff --git a/kmail/folderpropertiesdialog.ui b/kmail/folderpropertiesdialog.ui
index c21b2d4b..1428a54b 100644
--- a/kmail/folderpropertiesdialog.ui
+++ b/kmail/folderpropertiesdialog.ui
@@ -125,7 +125,7 @@
<cstring>mNormalIconButton</cstring>
</property>
</widget>
- <widget class="KIconButton" row="2" column="3">
+ <widget class="TDEIconButton" row="2" column="3">
<property name="name">
<cstring>mNormalIconButton</cstring>
</property>
@@ -173,7 +173,7 @@
</size>
</property>
</spacer>
- <widget class="KIconButton" row="2" column="6">
+ <widget class="TDEIconButton" row="2" column="6">
<property name="name">
<cstring>mUnreadIconButton</cstring>
</property>
diff --git a/kmail/folderrequester.cpp b/kmail/folderrequester.cpp
index 177e8caf..f2f7ec16 100644
--- a/kmail/folderrequester.cpp
+++ b/kmail/folderrequester.cpp
@@ -52,7 +52,7 @@ FolderRequester::FolderRequester( TQWidget *parent, KMFolderTree *tree )
edit->setReadOnly( true );
TQToolButton* button = new TQToolButton( this );
- button->setIconSet( TDEGlobal::iconLoader()->loadIconSet( "folder", KIcon::Small, 0 ) );
+ button->setIconSet( TDEGlobal::iconLoader()->loadIconSet( "folder", TDEIcon::Small, 0 ) );
connect( button, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotOpenDialog()) );
setSizePolicy( TQSizePolicy( TQSizePolicy::MinimumExpanding,
diff --git a/kmail/kmfawidgets.cpp b/kmail/kmfawidgets.cpp
index f5fa9f9a..493fa6c5 100644
--- a/kmail/kmfawidgets.cpp
+++ b/kmail/kmfawidgets.cpp
@@ -34,7 +34,7 @@ KMFilterActionWithAddressWidget::KMFilterActionWithAddressWidget( TQWidget* pare
mLineEdit->setName( "addressEdit" );
hbl->addWidget( mLineEdit, 1 /*stretch*/ );
mBtn = new TQPushButton( TQString() ,this );
- mBtn->setPixmap( BarIcon( "contents", KIcon::SizeSmall ) );
+ mBtn->setPixmap( BarIcon( "contents", TDEIcon::SizeSmall ) );
mBtn->setFixedHeight( mLineEdit->sizeHint().height() );
TQToolTip::add( mBtn, i18n( "Open Address Book" ) );
hbl->addWidget( mBtn );
diff --git a/kmail/kmfilterdlg.cpp b/kmail/kmfilterdlg.cpp
index 304219b9..9441b63d 100644
--- a/kmail/kmfilterdlg.cpp
+++ b/kmail/kmfilterdlg.cpp
@@ -248,9 +248,9 @@ KMFilterDlg::KMFilterDlg(TQWidget* parent, const char* name, bool popFilter, boo
hbox );
mFilterActionLabel->setEnabled( false );
- mFilterActionIconButton = new KIconButton( hbox );
+ mFilterActionIconButton = new TDEIconButton( hbox );
mFilterActionLabel->setBuddy( mFilterActionIconButton );
- mFilterActionIconButton->setIconType( KIcon::NoGroup, KIcon::Any, true );
+ mFilterActionIconButton->setIconType( TDEIcon::NoGroup, TDEIcon::Any, true );
mFilterActionIconButton->setIconSize( 16 );
mFilterActionIconButton->setIcon( "gear" );
mFilterActionIconButton->setEnabled( false );
@@ -594,19 +594,19 @@ KMFilterListBox::KMFilterListBox( const TQString & title, TQWidget *parent, cons
hb->setSpacing(4);
mBtnTop = new KPushButton( TQString(), hb );
mBtnTop->setAutoRepeat( true );
- mBtnTop->setIconSet( BarIconSet( "top", KIcon::SizeSmall ) );
+ mBtnTop->setIconSet( BarIconSet( "top", TDEIcon::SizeSmall ) );
mBtnTop->setMinimumSize( mBtnTop->sizeHint() * 1.2 );
mBtnUp = new KPushButton( TQString(), hb );
mBtnUp->setAutoRepeat( true );
- mBtnUp->setIconSet( BarIconSet( "up", KIcon::SizeSmall ) );
+ mBtnUp->setIconSet( BarIconSet( "up", TDEIcon::SizeSmall ) );
mBtnUp->setMinimumSize( mBtnUp->sizeHint() * 1.2 );
mBtnDown = new KPushButton( TQString(), hb );
mBtnDown->setAutoRepeat( true );
- mBtnDown->setIconSet( BarIconSet( "down", KIcon::SizeSmall ) );
+ mBtnDown->setIconSet( BarIconSet( "down", TDEIcon::SizeSmall ) );
mBtnDown->setMinimumSize( mBtnDown->sizeHint() * 1.2 );
mBtnBot = new KPushButton( TQString(), hb );
mBtnBot->setAutoRepeat( true );
- mBtnBot->setIconSet( BarIconSet( "bottom", KIcon::SizeSmall ) );
+ mBtnBot->setIconSet( BarIconSet( "bottom", TDEIcon::SizeSmall ) );
mBtnBot->setMinimumSize( mBtnBot->sizeHint() * 1.2 );
TQToolTip::add( mBtnTop, i18n("Top") );
TQToolTip::add( mBtnUp, i18n("Up") );
@@ -621,13 +621,13 @@ KMFilterListBox::KMFilterListBox( const TQString & title, TQWidget *parent, cons
hb = new TQHBox(this);
hb->setSpacing(4);
mBtnNew = new TQPushButton( TQString(), hb );
- mBtnNew->setPixmap( BarIcon( "filenew", KIcon::SizeSmall ) );
+ mBtnNew->setPixmap( BarIcon( "filenew", TDEIcon::SizeSmall ) );
mBtnNew->setMinimumSize( mBtnNew->sizeHint() * 1.2 );
mBtnCopy = new TQPushButton( TQString(), hb );
- mBtnCopy->setIconSet( BarIconSet( "editcopy", KIcon::SizeSmall ) );
+ mBtnCopy->setIconSet( BarIconSet( "editcopy", TDEIcon::SizeSmall ) );
mBtnCopy->setMinimumSize( mBtnCopy->sizeHint() * 1.2 );
mBtnDelete = new TQPushButton( TQString(), hb );
- mBtnDelete->setIconSet( BarIconSet( "editdelete", KIcon::SizeSmall ) );
+ mBtnDelete->setIconSet( BarIconSet( "editdelete", TDEIcon::SizeSmall ) );
mBtnDelete->setMinimumSize( mBtnDelete->sizeHint() * 1.2 );
mBtnRename = new TQPushButton( i18n("Rename..."), hb );
TQToolTip::add( mBtnNew, i18n("New") );
diff --git a/kmail/kmfilterdlg.h b/kmail/kmfilterdlg.h
index 3801d8be..e2d414b9 100644
--- a/kmail/kmfilterdlg.h
+++ b/kmail/kmfilterdlg.h
@@ -28,7 +28,7 @@ class TQPushButton;
class TQComboBox;
class TQWidgetStack;
class TQCheckBox;
-class KIconButton;
+class TDEIconButton;
class KKeyButton;
class TDEListView;
@@ -414,7 +414,7 @@ protected:
TQCheckBox *mConfigureShortcut;
TQCheckBox *mConfigureToolbar;
TQLabel *mFilterActionLabel;
- KIconButton *mFilterActionIconButton;
+ TDEIconButton *mFilterActionIconButton;
KKeyButton *mKeyButton;
TQGroupBox *mAdvOptsGroup;
TQVGroupBox *mGlobalsBox;
diff --git a/kmail/kmfolderdia.h b/kmail/kmfolderdia.h
index 95f7b31b..764ea897 100644
--- a/kmail/kmfolderdia.h
+++ b/kmail/kmfolderdia.h
@@ -45,7 +45,7 @@ class KMFolder;
class KMFolderTreeItem;
class KMFolderDir;
class KIntNumInput;
-class KIconButton;
+class TDEIconButton;
class KEditListBox;
namespace KPIM { class IdentityCombo; }
class KMFolderDialog;
@@ -141,9 +141,9 @@ private:
TQCheckBox *mAlarmsBlockedCheckBox;
TQCheckBox *mSharedSeenFlagsCheckBox;
TQLabel *mNormalIconLabel;
- KIconButton *mNormalIconButton;
+ TDEIconButton *mNormalIconButton;
TQLabel *mUnreadIconLabel;
- KIconButton *mUnreadIconButton;
+ TDEIconButton *mUnreadIconButton;
TQCheckBox *mIconsCheckBox;
TQCheckBox *mNewMailCheckBox;
TQCheckBox *mNotifyOnNewMailCheckBox;
diff --git a/kmail/kmfoldertree.cpp b/kmail/kmfoldertree.cpp
index 067568a1..ae340e7f 100644
--- a/kmail/kmfoldertree.cpp
+++ b/kmail/kmfoldertree.cpp
@@ -149,12 +149,12 @@ TQPixmap KMFolderTreeItem::normalIcon(int size) const
if (mFolder && mFolder->useCustomIcons() ) {
icon = mFolder->normalIconPath();
}
- KIconLoader * il = TDEGlobal::instance()->iconLoader();
- TQPixmap pm = il->loadIcon( icon, KIcon::Small, size,
- KIcon::DefaultState, 0, true );
+ TDEIconLoader * il = TDEGlobal::instance()->iconLoader();
+ TQPixmap pm = il->loadIcon( icon, TDEIcon::Small, size,
+ TDEIcon::DefaultState, 0, true );
if ( mFolder && pm.isNull() ) {
- pm = il->loadIcon( mFolder->normalIconPath(), KIcon::Small, size,
- KIcon::DefaultState, 0, true );
+ pm = il->loadIcon( mFolder->normalIconPath(), TDEIcon::Small, size,
+ TDEIcon::DefaultState, 0, true );
}
return pm;
@@ -170,25 +170,25 @@ TQPixmap KMFolderTreeItem::unreadIcon(int size) const
kmkernel->folderIsDraftOrOutbox( mFolder ) )
pm = normalIcon( size );
- KIconLoader * il = TDEGlobal::instance()->iconLoader();
+ TDEIconLoader * il = TDEGlobal::instance()->iconLoader();
if ( mFolder && mFolder->useCustomIcons() ) {
- pm = il->loadIcon( mFolder->unreadIconPath(), KIcon::Small, size,
- KIcon::DefaultState, 0, true );
+ pm = il->loadIcon( mFolder->unreadIconPath(), TDEIcon::Small, size,
+ TDEIcon::DefaultState, 0, true );
if ( pm.isNull() )
- pm = il->loadIcon( mFolder->normalIconPath(), KIcon::Small, size,
- KIcon::DefaultState, 0, true );
+ pm = il->loadIcon( mFolder->normalIconPath(), TDEIcon::Small, size,
+ TDEIcon::DefaultState, 0, true );
}
if ( pm.isNull() ) {
if ( mFolder && mFolder->noContent() ) {
- pm = il->loadIcon( "folder_grey_open", KIcon::Small, size,
- KIcon::DefaultState, 0, true );
+ pm = il->loadIcon( "folder_grey_open", TDEIcon::Small, size,
+ TDEIcon::DefaultState, 0, true );
} else {
if( kmkernel->iCalIface().isResourceFolder( mFolder ) )
pm = il->loadIcon( kmkernel->iCalIface().folderPixmap( type() ),
- KIcon::Small, size, KIcon::DefaultState, 0, true );
+ TDEIcon::Small, size, TDEIcon::DefaultState, 0, true );
if ( pm.isNull() )
- pm = il->loadIcon( "folder_open", KIcon::Small, size,
- KIcon::DefaultState, 0, true );
+ pm = il->loadIcon( "folder_open", TDEIcon::Small, size,
+ TDEIcon::DefaultState, 0, true );
}
}
diff --git a/kmail/kmheaders.cpp b/kmail/kmheaders.cpp
index 99091856..432c0213 100644
--- a/kmail/kmheaders.cpp
+++ b/kmail/kmheaders.cpp
@@ -2399,9 +2399,9 @@ void KMHeaders::contentsMouseMoveEvent( TQMouseEvent* e )
// Set pixmap
TQPixmap pixmap;
if( count == 1 )
- pixmap = TQPixmap( DesktopIcon("message", KIcon::SizeSmall) );
+ pixmap = TQPixmap( DesktopIcon("message", TDEIcon::SizeSmall) );
else
- pixmap = TQPixmap( DesktopIcon("tdemultiple", KIcon::SizeSmall) );
+ pixmap = TQPixmap( DesktopIcon("tdemultiple", TDEIcon::SizeSmall) );
// Calculate hotspot (as in Konqueror)
if( !pixmap.isNull() ) {
diff --git a/kmail/kmmimeparttree.cpp b/kmail/kmmimeparttree.cpp
index 3b17b16d..29d4b8f7 100644
--- a/kmail/kmmimeparttree.cpp
+++ b/kmail/kmmimeparttree.cpp
@@ -370,7 +370,7 @@ void KMMimePartTreeItem::setIconAndTextForType( const TQString & mime )
} else {
KMimeType::Ptr mtp = KMimeType::mimeType( mimetype );
setText( 1, (mtp && !mtp->comment().isEmpty()) ? mtp->comment() : mimetype );
- setPixmap( 0, mtp ? mtp->pixmap( KIcon::Small) : SmallIcon("unknown") );
+ setPixmap( 0, mtp ? mtp->pixmap( TDEIcon::Small) : SmallIcon("unknown") );
}
}
diff --git a/kmail/kmmsgpart.h b/kmail/kmmsgpart.h
index b49b5a30..4994800b 100644
--- a/kmail/kmmsgpart.h
+++ b/kmail/kmmsgpart.h
@@ -159,7 +159,7 @@ public:
/** Tries to find a good icon for the 'Content-Type' by scanning
the installed mimelnk files. Returns the found icon. If no matching
icon is found, the one for application/octet-stream is returned. */
- TQString iconName( int size = KIcon::Desktop ) const;
+ TQString iconName( int size = TDEIcon::Desktop ) const;
/** Get or set the 'Content-Transfer-Encoding' header field
The member functions that involve enumerated types (ints)
diff --git a/kmail/kmmsgpartdlg.cpp b/kmail/kmmsgpartdlg.cpp
index dc0815f8..dd92e863 100644
--- a/kmail/kmmsgpartdlg.cpp
+++ b/kmail/kmmsgpartdlg.cpp
@@ -323,7 +323,7 @@ void KMMsgPartDialog::slotMimeTypeChanged( const TQString & mimeType ) {
TQString tmp = mimeType; // get rid of const'ness
if ( mMimeType->validator() && mMimeType->validator()->validate( tmp, dummy )
== TQValidator::Acceptable )
- mIcon->setPixmap( KMimeType::mimeType( mimeType )->pixmap( KIcon::Desktop ) );
+ mIcon->setPixmap( KMimeType::mimeType( mimeType )->pixmap( TDEIcon::Desktop ) );
else
mIcon->setPixmap( DesktopIcon("unknown") );
}
diff --git a/kmail/kmstartup.cpp b/kmail/kmstartup.cpp
index 2473c871..c96a576d 100644
--- a/kmail/kmstartup.cpp
+++ b/kmail/kmstartup.cpp
@@ -251,7 +251,7 @@ void insertLibraryCataloguesAndIcons() {
};
TDELocale * l = TDEGlobal::locale();
- KIconLoader * il = TDEGlobal::iconLoader();
+ TDEIconLoader * il = TDEGlobal::iconLoader();
for ( unsigned int i = 0 ; i < sizeof catalogues / sizeof *catalogues ; ++i ) {
l->insertCatalogue( catalogues[i] );
il->addAppDir( catalogues[i] );
diff --git a/kmail/objecttreeparser.cpp b/kmail/objecttreeparser.cpp
index 7051542b..a5c862b9 100644
--- a/kmail/objecttreeparser.cpp
+++ b/kmail/objecttreeparser.cpp
@@ -733,7 +733,7 @@ namespace KMail {
void ObjectTreeParser::writeDecryptionInProgressBlock() {
assert( mReader );
// PENDING(marc) find an animated icon here:
- //const TQString iconName = TDEGlobal::instance()->iconLoader()->iconPath( "decrypted", KIcon::Small );
+ //const TQString iconName = TDEGlobal::instance()->iconLoader()->iconPath( "decrypted", TDEIcon::Small );
const TQString decryptedData = i18n("Encrypted data not shown");
PartMetaData messagePart;
messagePart.isDecryptable = true;
@@ -749,7 +749,7 @@ void ObjectTreeParser::writeDecryptionInProgressBlock() {
void ObjectTreeParser::writeDeferredDecryptionBlock() {
assert( mReader );
- const TQString iconName = TDEGlobal::instance()->iconLoader()->iconPath( "decrypted", KIcon::Small );
+ const TQString iconName = TDEGlobal::instance()->iconLoader()->iconPath( "decrypted", TDEIcon::Small );
const TQString decryptedData =
"<div style=\"font-size:large; text-align:center;padding-top:20pt;\">" +
i18n("This message is encrypted.") +
@@ -2010,7 +2010,7 @@ bool ObjectTreeParser::processApplicationMsTnefSubtype( partNode *node, ProcessR
TQString href = "file:" + KURL::encode_string( dir + TQDir::separator() + att->name() );
KMimeType::Ptr mimeType = KMimeType::mimeType( att->mimeTag() );
- TQString iconName = TDEGlobal::instance()->iconLoader()->iconPath( mimeType->icon( TQString(), false ), KIcon::Desktop );
+ TQString iconName = TDEGlobal::instance()->iconLoader()->iconPath( mimeType->icon( TQString(), false ), TDEIcon::Desktop );
htmlWriter()->queue( "<div><a href=\"" + href + "\"><img src=\"" +
iconName + "\" border=\"0\" style=\"max-width: 100%\">" + label +
diff --git a/kmail/partNode.cpp b/kmail/partNode.cpp
index 9bfe46b9..576a1c17 100644
--- a/kmail/partNode.cpp
+++ b/kmail/partNode.cpp
@@ -752,7 +752,7 @@ TQString partNode::asHREF( const TQString &place ) const
partNode::AttachmentDisplayInfo partNode::attachmentDisplayInfo() const
{
AttachmentDisplayInfo info;
- info.icon = msgPart().iconName( KIcon::Small );
+ info.icon = msgPart().iconName( TDEIcon::Small );
info.label = msgPart().name().stripWhiteSpace();
if ( info.label.isEmpty() )
info.label = msgPart().fileName();
diff --git a/kmail/recipientspicker.cpp b/kmail/recipientspicker.cpp
index 3ae2ad81..2e851272 100644
--- a/kmail/recipientspicker.cpp
+++ b/kmail/recipientspicker.cpp
@@ -63,7 +63,7 @@ void RecipientItem::setDistributionList( KPIM::DistributionList &list )
{
mDistributionList = list;
- mIcon = TDEGlobal::iconLoader()->loadIcon( "tdmconfig", KIcon::Small );
+ mIcon = TDEGlobal::iconLoader()->loadIcon( "tdmconfig", TDEIcon::Small );
mName = list.name();
mKey = list.name();
@@ -80,7 +80,7 @@ void RecipientItem::setDistributionList( KABC::DistributionList *list )
{
mDistributionList = list;
- mIcon = TDEGlobal::iconLoader()->loadIcon( "tdmconfig", KIcon::Small );
+ mIcon = TDEGlobal::iconLoader()->loadIcon( "tdmconfig", TDEIcon::Small );
mName = list->name();
mKey = list->name();
@@ -105,7 +105,7 @@ void RecipientItem::setAddressee( const KABC::Addressee &a,
if ( !img.isNull() )
mIcon = img.smoothScale( 20, 20, TQ_ScaleMin );
else
- mIcon = TDEGlobal::iconLoader()->loadIcon( "personal", KIcon::Small );
+ mIcon = TDEGlobal::iconLoader()->loadIcon( "personal", TDEIcon::Small );
mName = mAddressee.realName();
mKey = mAddressee.realName() + '|' + mEmail;
@@ -373,7 +373,7 @@ RecipientsPicker::RecipientsPicker( TQWidget *parent )
TQToolButton *button = new TQToolButton( this );
button->setIconSet( TDEGlobal::iconLoader()->loadIconSet(
- TDEApplication::reverseLayout() ? "clear_left":"locationbar_erase", KIcon::Small, 0 ) );
+ TDEApplication::reverseLayout() ? "clear_left":"locationbar_erase", TDEIcon::Small, 0 ) );
searchLayout->addWidget( button );
connect( button, TQT_SIGNAL( clicked() ), TQT_SLOT( resetSearch() ) );
diff --git a/kmail/redirectdialog.cpp b/kmail/redirectdialog.cpp
index 4cd26be0..c6585a5a 100644
--- a/kmail/redirectdialog.cpp
+++ b/kmail/redirectdialog.cpp
@@ -67,7 +67,7 @@ RedirectDialog::RedirectDialog( TQWidget *parent, const char *name,
mEditTo->setMinimumWidth( 300 );
mBtnTo = new TQPushButton( TQString(), hbox, "toBtn" );
- mBtnTo->setPixmap( BarIcon( "contents", KIcon::SizeSmall ) );
+ mBtnTo->setPixmap( BarIcon( "contents", TDEIcon::SizeSmall ) );
mBtnTo->setMinimumSize( mBtnTo->sizeHint() * 1.2 );
TQToolTip::add( mBtnTo, i18n("Use the Address-Selection Dialog") );
TQWhatsThis::add( mBtnTo, i18n("This button opens a separate dialog "
diff --git a/kmail/searchwindow.cpp b/kmail/searchwindow.cpp
index e5c00951..796cc8c0 100644
--- a/kmail/searchwindow.cpp
+++ b/kmail/searchwindow.cpp
@@ -93,9 +93,9 @@ class MatchListView : public TDEListView
TQPixmap pixmap;
if( mailList.count() == 1 )
- pixmap = TQPixmap( DesktopIcon("message", KIcon::SizeSmall) );
+ pixmap = TQPixmap( DesktopIcon("message", TDEIcon::SizeSmall) );
else
- pixmap = TQPixmap( DesktopIcon("tdemultiple", KIcon::SizeSmall) );
+ pixmap = TQPixmap( DesktopIcon("tdemultiple", TDEIcon::SizeSmall) );
d->setPixmap( pixmap );
return d;
diff --git a/kmail/simplestringlisteditor.cpp b/kmail/simplestringlisteditor.cpp
index 8520af84..cf58f98c 100644
--- a/kmail/simplestringlisteditor.cpp
+++ b/kmail/simplestringlisteditor.cpp
@@ -122,7 +122,7 @@ SimpleStringListEditor::SimpleStringListEditor( TQWidget * parent,
kdDebug(5006) << "Are you sure you want to use an Up button "
"without a Down button??" << endl;
mUpButton = new KPushButton( TQString(), this );
- mUpButton->setIconSet( BarIconSet( "up", KIcon::SizeSmall ) );
+ mUpButton->setIconSet( BarIconSet( "up", TDEIcon::SizeSmall ) );
mUpButton->setAutoDefault( false );
mUpButton->setEnabled( false ); // no selection yet
vlay->addWidget( mUpButton );
@@ -135,7 +135,7 @@ SimpleStringListEditor::SimpleStringListEditor( TQWidget * parent,
kdDebug(5006) << "Are you sure you want to use a Down button "
"without an Up button??" << endl;
mDownButton = new KPushButton( TQString(), this );
- mDownButton->setIconSet( BarIconSet( "down", KIcon::SizeSmall ) );
+ mDownButton->setIconSet( BarIconSet( "down", TDEIcon::SizeSmall ) );
mDownButton->setAutoDefault( false );
mDownButton->setEnabled( false ); // no selection yet
vlay->addWidget( mDownButton );
diff --git a/kmail/urlhandlermanager.cpp b/kmail/urlhandlermanager.cpp
index 1627cec6..7ce10ce1 100644
--- a/kmail/urlhandlermanager.cpp
+++ b/kmail/urlhandlermanager.cpp
@@ -654,7 +654,7 @@ namespace {
KURL file = window->tempFileUrlFromPartNode( node ).path();
if ( !file.isEmpty() ) {
- TQString icon = node->msgPart().iconName( KIcon::Small );
+ TQString icon = node->msgPart().iconName( TDEIcon::Small );
KURLDrag* urlDrag = new KURLDrag( file, window );
if ( !icon.isEmpty() ) {
TQPixmap iconMap( icon );
diff --git a/kmail/kmfolderdia.cpp b/kmail/kmfolderdia.cpp
index f2a32f6e..4bbfa8e6 100644
--- a/kmail/kmfolderdia.cpp
+++ b/kmail/kmfolderdia.cpp
@@ -362,9 +362,9 @@ KMail::FolderDiaGeneralTab::FolderDiaGeneralTab( KMFolderDialog* dlg,
mNormalIconLabel->setEnabled( false );
ihl->addWidget( mNormalIconLabel );
- mNormalIconButton = new KIconButton( this );
+ mNormalIconButton = new TDEIconButton( this );
mNormalIconLabel->setBuddy( mNormalIconButton );
- mNormalIconButton->setIconType( KIcon::NoGroup , KIcon::Any, true );
+ mNormalIconButton->setIconType( TDEIcon::NoGroup , TDEIcon::Any, true );
mNormalIconButton->setIconSize( 16 );
mNormalIconButton->setStrictIconSize( true );
mNormalIconButton->setFixedSize( 28, 28 );
@@ -377,9 +377,9 @@ KMail::FolderDiaGeneralTab::FolderDiaGeneralTab( KMFolderDialog* dlg,
mUnreadIconLabel->setEnabled( false );
ihl->addWidget( mUnreadIconLabel );
- mUnreadIconButton = new KIconButton( this );
+ mUnreadIconButton = new TDEIconButton( this );
mUnreadIconLabel->setBuddy( mUnreadIconButton );
- mUnreadIconButton->setIconType( KIcon::NoGroup, KIcon::Any, true );
+ mUnreadIconButton->setIconType( TDEIcon::NoGroup, TDEIcon::Any, true );
mUnreadIconButton->setIconSize( 16 );
mUnreadIconButton->setStrictIconSize( true );
mUnreadIconButton->setFixedSize( 28, 28 );
@@ -789,7 +789,7 @@ bool FolderDiaGeneralTab::save()
return true;
}
-void FolderDiaGeneralTab::slotChangeIcon( TQString icon ) // can't use a const-ref here, due to KIconButton's signal
+void FolderDiaGeneralTab::slotChangeIcon( TQString icon ) // can't use a const-ref here, due to TDEIconButton's signal
{
mUnreadIconButton->setIcon( icon );
}
diff --git a/kmail/kmsystemtray.cpp b/kmail/kmsystemtray.cpp
index 1eb9f467..2a3bd975 100644
--- a/kmail/kmsystemtray.cpp
+++ b/kmail/kmsystemtray.cpp
@@ -218,7 +218,7 @@ void KMSystemTray::updateCount()
// "This function is slow because it involves transformation to a TQImage,
// non-trivial computations and a transformation back to a TQBitmap."). Then
// I have to convert the resulting TQPixmap to a TQImage in order to overlay
// the light KMail icon with the number (because KIconEffect::overlay only
// works with TQImage). Finally the resulting TQImage has to be converted
// back to a TQPixmap.
// That's a lot of work for overlaying the KMail icon with the number of
@@ -235,7 +235,7 @@ void KMSystemTray::updateCount()
// Overlay the light KMail icon with the number image
TQImage iconWithNumberImage = mLightIconImage.copy();
- KIconEffect::overlay( iconWithNumberImage, numberImage );
+ TDEIconEffect::overlay( iconWithNumberImage, numberImage );
TQPixmap iconWithNumber;
iconWithNumber.convertFromImage( iconWithNumberImage );
@@ -218,7 +218,7 @@ void KMSystemTray::updateCount()
// non-trivial computations and a transformation back to a TQBitmap."). Then
// I have to convert the resulting TQPixmap to a TQImage in order to overlay
- // the light KMail icon with the number (because KIconEffect::overlay only
+ // the light KMail icon with the number (because TDEIconEffect::overlay only
// works with TQImage). Finally the resulting TQImage has to be converted
// back to a TQPixmap.